#!/bin/sh
# Example on using libaesop

# export AESOP_TUNNEL_ADDR=127.0.0.1
# export AESOP_ALLOW_IPV4TOIPV6=1

export AESOP_TUNNEL_PORT=3000
export LD_PRELOAD=`pwd`/libaesop.so.0

$*
